Query class

Annotation to define a query parameter.

@Query()
final String? status;
Annotations

Constructors

Query([String? name])
Create a Query annotation with the (optional) name.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the query parameter. If null, the field name is used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited