Route class

Annotation to define a route blueprint.

@Route('path')
class MyRoute extends _$MyRoute {}
Annotations

Constructors

Route(String path, {Type? parent})
Creates a Route annotation with the given path and (optionally) the parent.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
parent Type?
The parent route blueprint class.
final
path String
The path for this route.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited