fullPath method

String fullPath(
  1. Data data
)

Generate the full, populated path for this route using the supplied data.

This method will inject the data parameters into the path template and append any query parameters.

e.g. /user/:userId becomes /user/123?query=my%20query

Implementation

String fullPath(Data data) {
  final path = _injectParams(_fullPathTemplate, data);
  final query = _getQuery(data);

  return _appendQuery(path, query);
}