isActive method
Determine if this route is active in any way.
Implementation
bool isActive(GoRouterState state) {
return isCurrentRoute(state) || isParentRoute(state);
}
Determine if this route is active in any way.
bool isActive(GoRouterState state) {
return isCurrentRoute(state) || isParentRoute(state);
}