SimpleRouteData class abstract

A class that contains data to be injected into a route. This can be path parameters, query parameters, or "extra" data, or any combination of the three.

Constructors

SimpleRouteData()
Create a new SimpleRouteData.
const

Properties

extra Object?
Inject "extra" data into the GoRouterState.
no setter
hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, String>
Path parameters to be injected into the route.
no setter
query Map<String, String?>
Query parameters to be appended to the route.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited