simple_routes
library
Classes
ChildRoute <Parent extends BaseRoute >
A route that is a descendant of another route.
Annotation to define an extra parameter.
Path
Annotation to define a path parameter mapping.
Query
Annotation to define a query parameter.
Route
Annotation to define a route blueprint.
SimpleDataRoute <Data extends SimpleRouteData >
A route that contains one or more path and/or query parameters and/or
"extra" data.
SimpleRoute
A route that contains no parameters.
SimpleRouteData
A class that contains data to be injected into a route.
This can be path parameters, query parameters, or "extra" data, or any
combination of the three.