isCurrentRoute method
Determine if this route is an exact match for the current location.
This is useful for determining if a route is active.
Implementation
bool isCurrentRoute(GoRouterState state) {
return state.fullPath == _fullPathTemplate;
}
Determine if this route is an exact match for the current location.
This is useful for determining if a route is active.
bool isCurrentRoute(GoRouterState state) {
return state.fullPath == _fullPathTemplate;
}